Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddArgs ¶
func AddArgs(debugLogOpts *LoggingOptions, sharedArgs []string) []string
Types ¶
type LoggingOptions ¶
type LoggingOptions struct {
// LogLevel - choose verbosity level of at least 1 (least verbose).
// If not specified, reverts to default log level.
// Note - These logs may include sensitive information that is provided from your
// execution environment to your cloud provider (and which Pulumi may not even
// itself be aware of).
LogLevel *uint
// LogToStdErr specifies that all logs should be sent directly to stderr - making it
// more accessible and avoiding OS level buffering.
LogToStdErr bool
// FlowToPlugins reflects the logging settings to plugins as well.
FlowToPlugins bool
// Emit tracing to the specified endpoint. Use the file: scheme to write tracing data to a local file
Tracing string
// Print detailed debugging output during resource operations
Debug bool
}
Click to show internal directories.
Click to hide internal directories.