Documentation
¶
Overview ¶
Package optup contains functional options to be used with stack updates github.com/sdk/v2/go/x/auto Stack.Up(...optup.Option)
Index ¶
- type Option
- func AttachDebugger() Option
- func Color(color string) Option
- func ConfigFile(path string) Option
- func ContinueOnError() Option
- func DebugLogging(debugOpts debug.LoggingOptions) Option
- func Diff() Option
- func ErrorProgressStreams(writers ...io.Writer) Option
- func EventStreams(channels ...chan<- events.EngineEvent) Option
- func Exclude(urns []string) Option
- func ExcludeDependents() Option
- func ExpectNoChanges() Option
- func Message(message string) Option
- func Parallel(n int) Option
- func Plan(path string) Option
- func PolicyPackConfigs(paths ...string) Option
- func PolicyPacks(packs ...string) Option
- func ProgressStreams(writers ...io.Writer) Option
- func Refresh() Option
- func Replace(urns []string) Option
- func RunProgram(f bool) Option
- func ShowSecrets(show bool) Option
- func SuppressOutputs() Option
- func SuppressProgress() Option
- func Target(urns []string) Option
- func TargetDependents() Option
- func UserAgent(agent string) Option
- type Options
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Option ¶
type Option interface {
ApplyOption(*Options)
}
Option is a parameter to be applied to a Stack.Up() operation
func AttachDebugger ¶ added in v3.132.0
func AttachDebugger() Option
AttachDebugger will run the process under a debugger, and pause until a debugger is attached
func Color ¶ added in v3.146.0
Color allows specifying whether to colorize output. Choices are: always, never, raw, auto (default "auto")
func ConfigFile ¶ added in v3.140.0
ConfigFile specifies a file to use for configuration values rather than detecting the file name
func ContinueOnError ¶ added in v3.118.0
func ContinueOnError() Option
ContinueOnError will continue to perform the update operation despite the occurrence of errors.
func DebugLogging ¶
func DebugLogging(debugOpts debug.LoggingOptions) Option
DebugLogging provides options for verbose logging to standard error, and enabling plugin logs.
func ErrorProgressStreams ¶ added in v3.37.0
ErrorProgressStreams allows specifying one or more io.Writers to redirect incremental update stderr
func EventStreams ¶
func EventStreams(channels ...chan<- events.EngineEvent) Option
EventStreams allows specifying one or more channels to receive the Pulumi event stream
func ExcludeDependents ¶ added in v3.166.0
func ExcludeDependents() Option
ExcludeDependents allows ignoring of dependent targets discovered but not specified in the Exclude list
func ExpectNoChanges ¶
func ExpectNoChanges() Option
ExpectNoChanges will cause the update to return an error if any changes occur
func Parallel ¶
Parallel is the number of resource operations to run in parallel at once during the update (1 for no parallelism). Defaults to unbounded. (default 2147483647)
func PolicyPackConfigs ¶ added in v3.174.0
PolicyPackConfigs specifies one or more paths to JSON files containing the config for the policy pack
func PolicyPacks ¶ added in v3.174.0
PolicyPacks specifies one or more policy packs to run as part of this update
func ProgressStreams ¶
ProgressStreams allows specifying one or more io.Writers to redirect incremental update stdout
func Refresh ¶ added in v3.105.0
func Refresh() Option
Refresh will refresh the stack's state before the update.
func RunProgram ¶ added in v3.180.0
RunProgram runs the program in the workspace to perform the refresh.
func ShowSecrets ¶ added in v3.35.1
ShowSecrets configures whether to show config secrets when they appear.
func SuppressOutputs ¶ added in v3.109.0
func SuppressOutputs() Option
Suppress display of stack outputs (in case they contain sensitive values)
func SuppressProgress ¶ added in v3.109.0
func SuppressProgress() Option
Suppress display of periodic progress dots
func TargetDependents ¶
func TargetDependents() Option
TargetDependents allows updating of dependent targets discovered but not specified in the Target list
type Options ¶
type Options struct {
// Parallel is the number of resource operations to run in parallel at once
// (1 for no parallelism). Defaults to unbounded. (default 2147483647)
Parallel int
// Message (optional) to associate with the update operation
Message string
// Return an error if any changes occur during this update
ExpectNoChanges bool
// Diff displays operation as a rich diff showing the overall change
Diff bool
// Specify resources to replace
Replace []string
// Specify an exclusive list of resource URNs to update
Target []string
// Allows updating of dependent targets discovered but not specified in the Target list
TargetDependents bool
// Specify an exclusive of resource URNs to ignore
Exclude []string
// Allows ignoring of dependent targets discovered but not specified in the Exclude list
ExcludeDependents bool
// DebugLogOpts specifies additional settings for debug logging
DebugLogOpts debug.LoggingOptions
// ProgressStreams allows specifying one or more io.Writers to redirect incremental update stdout
ProgressStreams []io.Writer
// ErrorProgressStreams allows specifying one or more io.Writers to redirect incremental update stderr
ErrorProgressStreams []io.Writer
// EventStreams allows specifying one or more channels to receive the Pulumi event stream
EventStreams []chan<- events.EngineEvent
// UserAgent specifies the agent responsible for the update, stored in backends as "environment.exec.agent"
UserAgent string
// Colorize output. Choices are: always, never, raw, auto (default "auto")
Color string
// Use the update plan at the given path.
Plan string
// Run one or more policy packs as part of this update
PolicyPacks []string
// Path to JSON file containing the config for the policy pack of the corresponding "--policy-pack" flag
PolicyPackConfigs []string
// Show config secrets when they appear.
ShowSecrets *bool
// Refresh will refresh the stack's state before the update.
Refresh bool
// Suppress display of periodic progress dots
SuppressProgress bool
// Suppress display of stack outputs (in case they contain sensitive values)
SuppressOutputs bool
// ContinueOnError will continue to perform the update operation despite the occurrence of errors.
ContinueOnError bool
// AttachDebugger will run the process under a debugger, and pause until a debugger is attached
AttachDebugger bool
// Run using the configuration values in the specified file rather than detecting the file name
ConfigFile string
// When set to true, run the program in the workspace to perform the refresh.
RunProgram *bool
}
Options is an implementation detail